//
//  ETTrackingSession.h
//  EcondaTracking
//
//  Copyright (c) 2002-2011  econda GmbH Karlsruhe
//  All rights reserved.
//

#import <Foundation/Foundation.h>


typedef enum {
	ETTransmitModeImmediatelyAsync = 0,
	ETTransmitModeImmediatelySync,
    ETTransmitModeLaterBatch
} ETTransmitMode;


@class ETTrackingPageView;

/**
 * ETTrackingSession is the representation of one usage of your application.
 * You can collect and submit several PageView-Objects with a session.
 */

@interface ETTrackingSession : NSObject



/**----------------------------------------------------
 * @name Creating and Initializing Tracking Sessions
 * ---------------------------------------------------
 */

/** Initialize a Tracking Session with the given parameters
 
 @param clientKey your econda account registration key
 @param secure whether to transmit with https or http
 */

- (id)initWithClientKey:(NSString*)clientKey
                 secure:(BOOL)secure;


/** Initialize a Tracking Session with the given parameters
 
 @param clientKey your econda account registration key
 @param secure whether to transmit with https or http
 @param batchAutoTransmitTimeout autotransmit collected pageviews after x seconds
 */

-   (id)initWithClientKey:(NSString*)clientKey
                   secure:(BOOL)secure
 batchAutoTransmitTimeout:(int)batchAutoTransmitTimeout;



/**----------------------------------------------------
 * @name Customize behaviour
 * ---------------------------------------------------
 */

/**
 */
@property (nonatomic, assign) int batchAutoTransmitTimeout;

/**
 */
@property (nonatomic, assign) int samplingRate;




/**----------------------------------------------------
 * @name Common methods
 * ---------------------------------------------------
 */


/** Registers a pageView for later submission 
 
 @param pageView pageView
 @param transmitMode transmitMode
 */
- (void)addPageView:(ETTrackingPageView*)pageView transmitMode:(ETTransmitMode)transmitMode;


/** You can indicate by calling of this method, that the application user has restarted usage of your application.
 */
- (void)nextSession;


/** Transmit all collected data.
 
 @param synchron synchron
 */
- (void)submitBatch:(BOOL)synchron;



@end
